@@ -1,12 +1,12 @@
 /*
     __ _____ _____ _____
  __|  |   __|     |   | |  JSON for Modern C++ (test suite)
-|  |  |__   |  |  | | | |  version 3.5.0
+|  |  |__   |  |  | | | |  version 3.7.0
 |_____|_____|_____|_|___|  https://github.com/nlohmann/json
 
 Licensed under the MIT License <http://opensource.org/licenses/MIT>.
 SPDX-License-Identifier: MIT
-Copyright (c) 2013-2018 Niels Lohmann <http://nlohmann.me>.
+Copyright (c) 2013-2019 Niels Lohmann <http://nlohmann.me>.
 
 Permission is hereby  granted, free of charge, to any  person obtaining a copy
 of this software and associated  documentation files (the "Software"), to deal
@@ -27,11 +27,13 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE  OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
 
-#include "catch.hpp"
+#include "doctest_compatibility.h"
 
 #include <nlohmann/json.hpp>
 using nlohmann::json;
 
+namespace
+{
 // helper function to check std::less<json::value_t>
 // see https://en.cppreference.com/w/cpp/utility/functional/less
 template <typename A, typename B, typename U = std::less<json::value_t>>
@@ -39,6 +41,7 @@ bool f(A a, B b, U u = U())
 {
     return u(a, b);
 }
+}
 
 TEST_CASE("lexicographical comparison operators")
 {
@@ -74,8 +77,8 @@ TEST_CASE("lexicographical comparison operators")
             {
                 for (size_t j = 0; j < j_types.size(); ++j)
                 {
-                    CAPTURE(i);
-                    CAPTURE(j);
+                    CAPTURE(i)
+                    CAPTURE(j)
                     // check precomputed values
                     CHECK(operator<(j_types[i], j_types[j]) == expected[i][j]);
                     CHECK(f(j_types[i], j_types[j]) == expected[i][j]);
@@ -124,10 +127,10 @@ TEST_CASE("lexicographical comparison operators")
             {
                 for (size_t j = 0; j < j_values.size(); ++j)
                 {
-                    CAPTURE(i);
-                    CAPTURE(j);
-                    CAPTURE(j_values[i]);
-                    CAPTURE(j_values[j]);
+                    CAPTURE(i)
+                    CAPTURE(j)
+                    CAPTURE(j_values[i])
+                    CAPTURE(j_values[j])
                     // check precomputed values
                     CHECK( (j_values[i] == j_values[j]) == expected[i][j] );
                 }
@@ -154,8 +157,8 @@ TEST_CASE("lexicographical comparison operators")
             {
                 for (size_t j = 0; j < j_values.size(); ++j)
                 {
-                    CAPTURE(i);
-                    CAPTURE(j);
+                    CAPTURE(i)
+                    CAPTURE(j)
                     // check definition
                     CHECK( (j_values[i] != j_values[j]) == not(j_values[i] == j_values[j]) );
                 }
@@ -195,10 +198,10 @@ TEST_CASE("lexicographical comparison operators")
             {
                 for (size_t j = 0; j < j_values.size(); ++j)
                 {
-                    CAPTURE(i);
-                    CAPTURE(j);
-                    CAPTURE(j_values[i]);
-                    CAPTURE(j_values[j]);
+                    CAPTURE(i)
+                    CAPTURE(j)
+                    CAPTURE(j_values[i])
+                    CAPTURE(j_values[j])
                     // check precomputed values
                     CHECK( (j_values[i] < j_values[j]) == expected[i][j] );
                 }
@@ -208,7 +211,7 @@ TEST_CASE("lexicographical comparison operators")
             json j_discarded(json::value_t::discarded);
             for (size_t i = 0; i < j_values.size(); ++i)
             {
-                CAPTURE(i);
+                CAPTURE(i)
                 CHECK( (j_values[i] < j_discarded) == false);
                 CHECK( (j_discarded < j_values[i]) == false);
                 CHECK( (j_discarded < j_discarded) == false);
@@ -221,8 +224,8 @@ TEST_CASE("lexicographical comparison operators")
             {
                 for (size_t j = 0; j < j_values.size(); ++j)
                 {
-                    CAPTURE(i);
-                    CAPTURE(j);
+                    CAPTURE(i)
+                    CAPTURE(j)
                     // check definition
                     CHECK( (j_values[i] <= j_values[j]) == not(j_values[j] < j_values[i]) );
                 }
@@ -235,8 +238,8 @@ TEST_CASE("lexicographical comparison operators")
             {
                 for (size_t j = 0; j < j_values.size(); ++j)
                 {
-                    CAPTURE(i);
-                    CAPTURE(j);
+                    CAPTURE(i)
+                    CAPTURE(j)
                     // check definition
                     CHECK( (j_values[i] > j_values[j]) == (j_values[j] < j_values[i]) );
                 }
@@ -249,8 +252,8 @@ TEST_CASE("lexicographical comparison operators")
             {
                 for (size_t j = 0; j < j_values.size(); ++j)
                 {
-                    CAPTURE(i);
-                    CAPTURE(j);
+                    CAPTURE(i)
+                    CAPTURE(j)
                     // check definition
                     CHECK( (j_values[i] >= j_values[j]) == not(j_values[i] < j_values[j]) );
                 }
