@@ -1,7 +1,7 @@
 /*
     __ _____ _____ _____
  __|  |   __|     |   | |  JSON for Modern C++ (test suite)
-|  |  |__   |  |  | | | |  version 3.6.1
+|  |  |__   |  |  | | | |  version 3.7.0
 |_____|_____|_____|_|___|  https://github.com/nlohmann/json
 
 Licensed under the MIT License <http://opensource.org/licenses/MIT>.
@@ -27,11 +27,21 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE  OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
 
-#include "catch.hpp"
+#include "doctest_compatibility.h"
+DOCTEST_GCC_SUPPRESS_WARNING("-Wfloat-equal")
+
+// for some reason including this after the json header leads to linker errors with VS 2017...
+#include <locale>
 
 #define private public
 #include <nlohmann/json.hpp>
 using nlohmann::json;
+#undef private
+
+#include <fstream>
+#include <sstream>
+#include <list>
+#include <cstdio>
 
 #if (defined(__cplusplus) && __cplusplus >= 201703L) || (defined(_HAS_CXX17) && _HAS_CXX17 == 1) // fix for issue #464
     #define JSON_HAS_CPP_17
@@ -43,10 +53,6 @@ using nlohmann::json;
 
 #include "fifo_map.hpp"
 
-#include <fstream>
-#include <list>
-#include <cstdio>
-
 /////////////////////////////////////////////////////////////////////
 // for #972
 /////////////////////////////////////////////////////////////////////
@@ -287,7 +293,7 @@ TEST_CASE("regression tests")
         int number = j["Number"];
         CHECK(number == 100);
         float foo = j["Foo"];
-        CHECK(foo == Approx(42.42));
+        CHECK(static_cast<double>(foo) == Approx(42.42));
     }
 
     SECTION("issue #89 - nonstandard integer type")
@@ -297,8 +303,7 @@ TEST_CASE("regression tests")
             nlohmann::basic_json<std::map, std::vector, std::string, bool, int32_t, uint32_t, float>;
         custom_json j;
         j["int_1"] = 1;
-        // we need to cast to int to compile with Catch - the value is int32_t
-        CHECK(static_cast<int>(j["int_1"]) == 1);
+        CHECK(j["int_1"] == 1);
 
         // tests for correct handling of non-standard integers that overflow the type selected by the user
 
@@ -691,8 +696,9 @@ TEST_CASE("regression tests")
 
     SECTION("issue #329 - serialized value not always can be parsed")
     {
-        CHECK_THROWS_AS(json::parse("22e2222"), json::out_of_range&);
-        CHECK_THROWS_WITH(json::parse("22e2222"),
+        json _;
+        CHECK_THROWS_AS(_ = json::parse("22e2222"), json::out_of_range&);
+        CHECK_THROWS_WITH(_ = json::parse("22e2222"),
                           "[json.exception.out_of_range.406] number overflow parsing '22e2222'");
     }
 
@@ -714,7 +720,7 @@ TEST_CASE("regression tests")
         };
 
         check_roundtrip(100000000000.1236);
-        check_roundtrip(std::numeric_limits<json::number_float_t>::max());
+        check_roundtrip((std::numeric_limits<json::number_float_t>::max)());
 
         // Some more numbers which fail to roundtrip when serialized with digits10 significand digits (instead of max_digits10)
         check_roundtrip(1.541888611948064e-17);
@@ -757,8 +763,9 @@ TEST_CASE("regression tests")
     SECTION("issue #366 - json::parse on failed stream gets stuck")
     {
         std::ifstream f("file_not_found.json");
-        CHECK_THROWS_AS(json::parse(f), json::parse_error&);
-        CHECK_THROWS_WITH(json::parse(f), "[json.exception.parse_error.101] parse error at line 1, column 1: syntax error while parsing value - unexpected end of input; expected '[', '{', or a literal");
+        json _;
+        CHECK_THROWS_AS(_ = json::parse(f), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::parse(f), "[json.exception.parse_error.101] parse error at line 1, column 1: syntax error while parsing value - unexpected end of input; expected '[', '{', or a literal");
     }
 
     SECTION("issue #367 - calling stream at EOF")
@@ -953,50 +960,55 @@ TEST_CASE("regression tests")
     {
         // original test case
         std::vector<uint8_t> vec {0x65, 0xf5, 0x0a, 0x48, 0x21};
-        CHECK_THROWS_AS(json::from_cbor(vec), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec),
+        json _;
+        CHECK_THROWS_AS(_ = json::from_cbor(vec), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec),
                           "[json.exception.parse_error.110] parse error at byte 6: syntax error while parsing CBOR string: unexpected end of input");
     }
 
     SECTION("issue #407 - Heap-buffer-overflow (OSS-Fuzz issue 343)")
     {
+        json _;
+
         // original test case: incomplete float64
         std::vector<uint8_t> vec1 {0xcb, 0x8f, 0x0a};
-        CHECK_THROWS_AS(json::from_msgpack(vec1), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_msgpack(vec1),
+        CHECK_THROWS_AS(_ = json::from_msgpack(vec1), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_msgpack(vec1),
                           "[json.exception.parse_error.110] parse error at byte 4: syntax error while parsing MessagePack number: unexpected end of input");
 
         // related test case: incomplete float32
         std::vector<uint8_t> vec2 {0xca, 0x8f, 0x0a};
-        CHECK_THROWS_AS(json::from_msgpack(vec2), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_msgpack(vec2),
+        CHECK_THROWS_AS(_ = json::from_msgpack(vec2), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_msgpack(vec2),
                           "[json.exception.parse_error.110] parse error at byte 4: syntax error while parsing MessagePack number: unexpected end of input");
 
         // related test case: incomplete Half-Precision Float (CBOR)
         std::vector<uint8_t> vec3 {0xf9, 0x8f};
-        CHECK_THROWS_AS(json::from_cbor(vec3), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec3),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec3), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec3),
                           "[json.exception.parse_error.110] parse error at byte 3: syntax error while parsing CBOR number: unexpected end of input");
 
         // related test case: incomplete Single-Precision Float (CBOR)
         std::vector<uint8_t> vec4 {0xfa, 0x8f, 0x0a};
-        CHECK_THROWS_AS(json::from_cbor(vec4), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec4),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec4), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec4),
                           "[json.exception.parse_error.110] parse error at byte 4: syntax error while parsing CBOR number: unexpected end of input");
 
         // related test case: incomplete Double-Precision Float (CBOR)
         std::vector<uint8_t> vec5 {0xfb, 0x8f, 0x0a};
-        CHECK_THROWS_AS(json::from_cbor(vec5), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec5),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec5), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec5),
                           "[json.exception.parse_error.110] parse error at byte 4: syntax error while parsing CBOR number: unexpected end of input");
     }
 
     SECTION("issue #408 - Heap-buffer-overflow (OSS-Fuzz issue 344)")
     {
+        json _;
+
         // original test case
         std::vector<uint8_t> vec1 {0x87};
-        CHECK_THROWS_AS(json::from_msgpack(vec1), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_msgpack(vec1),
+        CHECK_THROWS_AS(_ = json::from_msgpack(vec1), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_msgpack(vec1),
                           "[json.exception.parse_error.110] parse error at byte 2: syntax error while parsing MessagePack string: unexpected end of input");
 
         // more test cases for MessagePack
@@ -1009,7 +1021,7 @@ TEST_CASE("regression tests")
                 })
         {
             std::vector<uint8_t> vec(1, static_cast<uint8_t>(b));
-            CHECK_THROWS_AS(json::from_msgpack(vec), json::parse_error&);
+            CHECK_THROWS_AS(_ = json::from_msgpack(vec), json::parse_error&);
         }
 
         // more test cases for CBOR
@@ -1024,37 +1036,39 @@ TEST_CASE("regression tests")
                 })
         {
             std::vector<uint8_t> vec(1, static_cast<uint8_t>(b));
-            CHECK_THROWS_AS(json::from_cbor(vec), json::parse_error&);
+            CHECK_THROWS_AS(_ = json::from_cbor(vec), json::parse_error&);
         }
 
         // special case: empty input
         std::vector<uint8_t> vec2;
-        CHECK_THROWS_AS(json::from_cbor(vec2), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec2),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec2), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec2),
                           "[json.exception.parse_error.110] parse error at byte 1: syntax error while parsing CBOR value: unexpected end of input");
-        CHECK_THROWS_AS(json::from_msgpack(vec2), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_msgpack(vec2),
+        CHECK_THROWS_AS(_ = json::from_msgpack(vec2), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_msgpack(vec2),
                           "[json.exception.parse_error.110] parse error at byte 1: syntax error while parsing MessagePack value: unexpected end of input");
     }
 
     SECTION("issue #411 - Heap-buffer-overflow (OSS-Fuzz issue 366)")
     {
+        json _;
+
         // original test case: empty UTF-8 string (indefinite length)
         std::vector<uint8_t> vec1 {0x7f};
-        CHECK_THROWS_AS(json::from_cbor(vec1), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec1),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec1), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec1),
                           "[json.exception.parse_error.110] parse error at byte 2: syntax error while parsing CBOR string: unexpected end of input");
 
         // related test case: empty array (indefinite length)
         std::vector<uint8_t> vec2 {0x9f};
-        CHECK_THROWS_AS(json::from_cbor(vec2), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec2),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec2), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec2),
                           "[json.exception.parse_error.110] parse error at byte 2: syntax error while parsing CBOR value: unexpected end of input");
 
         // related test case: empty map (indefinite length)
         std::vector<uint8_t> vec3 {0xbf};
-        CHECK_THROWS_AS(json::from_cbor(vec3), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec3),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec3), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec3),
                           "[json.exception.parse_error.110] parse error at byte 2: syntax error while parsing CBOR string: unexpected end of input");
     }
 
@@ -1081,26 +1095,28 @@ TEST_CASE("regression tests")
             0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60,
             0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60
         };
-        CHECK_THROWS_AS(json::from_cbor(vec), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec),
+
+        json _;
+        CHECK_THROWS_AS(_ = json::from_cbor(vec), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec),
                           "[json.exception.parse_error.113] parse error at byte 2: syntax error while parsing CBOR string: expected length specification (0x60-0x7B) or indefinite string type (0x7F); last byte: 0x98");
 
         // related test case: nonempty UTF-8 string (indefinite length)
         std::vector<uint8_t> vec1 {0x7f, 0x61, 0x61};
-        CHECK_THROWS_AS(json::from_cbor(vec1), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec1),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec1), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec1),
                           "[json.exception.parse_error.110] parse error at byte 4: syntax error while parsing CBOR string: unexpected end of input");
 
         // related test case: nonempty array (indefinite length)
         std::vector<uint8_t> vec2 {0x9f, 0x01};
-        CHECK_THROWS_AS(json::from_cbor(vec2), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec2),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec2), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec2),
                           "[json.exception.parse_error.110] parse error at byte 3: syntax error while parsing CBOR value: unexpected end of input");
 
         // related test case: nonempty map (indefinite length)
         std::vector<uint8_t> vec3 {0xbf, 0x61, 0x61, 0x01};
-        CHECK_THROWS_AS(json::from_cbor(vec3), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec3),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec3), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec3),
                           "[json.exception.parse_error.110] parse error at byte 5: syntax error while parsing CBOR string: unexpected end of input");
     }
 
@@ -1134,8 +1150,10 @@ TEST_CASE("regression tests")
             0x96, 0x96, 0xb4, 0xb4, 0xfa, 0x94, 0x94, 0x61,
             0x61, 0x61, 0x61, 0x61, 0x61, 0x61, 0x61, 0xfa
         };
-        CHECK_THROWS_AS(json::from_cbor(vec1), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec1),
+
+        json _;
+        CHECK_THROWS_AS(_ = json::from_cbor(vec1), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec1),
                           "[json.exception.parse_error.113] parse error at byte 13: syntax error while parsing CBOR string: expected length specification (0x60-0x7B) or indefinite string type (0x7F); last byte: 0xB4");
 
         // related test case: double-precision
@@ -1148,15 +1166,16 @@ TEST_CASE("regression tests")
             0x96, 0x96, 0xb4, 0xb4, 0xfa, 0x94, 0x94, 0x61,
             0x61, 0x61, 0x61, 0x61, 0x61, 0x61, 0x61, 0xfb
         };
-        CHECK_THROWS_AS(json::from_cbor(vec2), json::parse_error&);
-        CHECK_THROWS_WITH(json::from_cbor(vec2),
+        CHECK_THROWS_AS(_ = json::from_cbor(vec2), json::parse_error&);
+        CHECK_THROWS_WITH(_ = json::from_cbor(vec2),
                           "[json.exception.parse_error.113] parse error at byte 13: syntax error while parsing CBOR string: expected length specification (0x60-0x7B) or indefinite string type (0x7F); last byte: 0xB4");
     }
 
     SECTION("issue #452 - Heap-buffer-overflow (OSS-Fuzz issue 585)")
     {
         std::vector<uint8_t> vec = {'-', '0', '1', '2', '2', '7', '4'};
-        CHECK_THROWS_AS(json::parse(vec), json::parse_error&);
+        json _;
+        CHECK_THROWS_AS(_ = json::parse(vec), json::parse_error&);
     }
 
     SECTION("issue #454 - doubles are printed as integers")
@@ -1304,8 +1323,9 @@ TEST_CASE("regression tests")
 
     SECTION("issue #575 - heap-buffer-overflow (OSS-Fuzz 1400)")
     {
+        json _;
         std::vector<uint8_t> vec = {'"', '\\', '"', 'X', '"', '"'};
-        CHECK_THROWS_AS(json::parse(vec), json::parse_error&);
+        CHECK_THROWS_AS(_ = json::parse(vec), json::parse_error&);
     }
 
     SECTION("issue #600 - how does one convert a map in Json back to std::map?")
@@ -1344,7 +1364,8 @@ TEST_CASE("regression tests")
     SECTION("issue #602 - BOM not skipped when using json:parse(iterator)")
     {
         std::string i = "\xef\xbb\xbf{\n   \"foo\": true\n}";
-        CHECK_NOTHROW(json::parse(i.begin(), i.end()));
+        json _;
+        CHECK_NOTHROW(_ = json::parse(i.begin(), i.end()));
     }
 
     SECTION("issue #702 - conversion from valarray<double> to json fails to build")
@@ -1407,7 +1428,8 @@ TEST_CASE("regression tests")
             ); // handle different exceptions as 'file not found', 'permission denied'
 
             is.open("test/data/regression/working_file.json");
-            CHECK_NOTHROW(nlohmann::json::parse(is));
+            json _;
+            CHECK_NOTHROW(_ = nlohmann::json::parse(is));
         }
 
         {
@@ -1420,7 +1442,8 @@ TEST_CASE("regression tests")
 
             is.open("test/data/json_nlohmann_tests/all_unicode.json.cbor",
                     std::ios_base::in | std::ios_base::binary);
-            CHECK_NOTHROW(nlohmann::json::from_cbor(is));
+            json _;
+            CHECK_NOTHROW(_ = nlohmann::json::from_cbor(is));
         }
     }
 
@@ -1500,13 +1523,14 @@ TEST_CASE("regression tests")
 
     SECTION("issue #962 - Timeout (OSS-Fuzz 6034)")
     {
+        json _;
         std::vector<uint8_t> v_ubjson = {'[', '$', 'Z', '#', 'L', 0x78, 0x28, 0x00, 0x68, 0x28, 0x69, 0x69, 0x17};
-        CHECK_THROWS_AS(json::from_ubjson(v_ubjson), json::out_of_range&);
+        CHECK_THROWS_AS(_ = json::from_ubjson(v_ubjson), json::out_of_range&);
         //CHECK_THROWS_WITH(json::from_ubjson(v_ubjson),
         //                  "[json.exception.out_of_range.408] excessive array size: 8658170730974374167");
 
         v_ubjson[0] = '{';
-        CHECK_THROWS_AS(json::from_ubjson(v_ubjson), json::out_of_range&);
+        CHECK_THROWS_AS(_ = json::from_ubjson(v_ubjson), json::out_of_range&);
         //CHECK_THROWS_WITH(json::from_ubjson(v_ubjson),
         //                  "[json.exception.out_of_range.408] excessive object size: 8658170730974374167");
     }
@@ -1780,7 +1804,8 @@ TEST_CASE("regression tests")
     }
 }
 
-TEST_CASE("regression tests, exceptions dependent", "[!throws]")
+#if not defined(JSON_NOEXCEPTION)
+TEST_CASE("regression tests, exceptions dependent")
 {
     SECTION("issue #1340 - eof not set on exhausted input stream")
     {
@@ -1792,3 +1817,14 @@ TEST_CASE("regression tests, exceptions dependent", "[!throws]")
         CHECK(s.eof());
     }
 }
+#endif
+
+/////////////////////////////////////////////////////////////////////
+// for #1642
+/////////////////////////////////////////////////////////////////////
+template <typename T> class array {};
+template <typename T> class object {};
+template <typename T> class string {};
+template <typename T> class number_integer {};
+template <typename T> class number_unsigned {};
+template <typename T> class number_float {};
