@@ -1,12 +1,12 @@
 /*
     __ _____ _____ _____
  __|  |   __|     |   | |  JSON for Modern C++ (test suite)
-|  |  |__   |  |  | | | |  version 3.5.0
+|  |  |__   |  |  | | | |  version 3.7.0
 |_____|_____|_____|_|___|  https://github.com/nlohmann/json
 
 Licensed under the MIT License <http://opensource.org/licenses/MIT>.
 SPDX-License-Identifier: MIT
-Copyright (c) 2013-2018 Niels Lohmann <http://nlohmann.me>.
+Copyright (c) 2013-2019 Niels Lohmann <http://nlohmann.me>.
 
 Permission is hereby  granted, free of charge, to any  person obtaining a copy
 of this software and associated  documentation files (the "Software"), to deal
@@ -27,7 +27,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE  OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
 
-#include "catch.hpp"
+#include "doctest_compatibility.h"
 
 #include <nlohmann/json.hpp>
 using nlohmann::json;
@@ -77,9 +77,10 @@ TEST_CASE("compliance tests from json.org")
                     "test/data/json_tests/fail33.json"
                 })
         {
-            CAPTURE(filename);
+            CAPTURE(filename)
             std::ifstream f(filename);
-            CHECK_THROWS_AS(json::parse(f), json::parse_error&);
+            json _;
+            CHECK_THROWS_AS(_ = json::parse(f), json::parse_error&);
         }
     }
 
@@ -95,7 +96,7 @@ TEST_CASE("compliance tests from json.org")
                     "test/data/json_tests/fail10.json",
                 })
         {
-            CAPTURE(filename);
+            CAPTURE(filename)
             std::ifstream f(filename);
             json j;
             CHECK_NOTHROW(f >> j);
@@ -111,7 +112,7 @@ TEST_CASE("compliance tests from json.org")
                     "test/data/json_tests/pass3.json"
                 })
         {
-            CAPTURE(filename);
+            CAPTURE(filename)
             std::ifstream f(filename);
             json j;
             CHECK_NOTHROW(f >> j);
@@ -127,8 +128,8 @@ TEST_CASE("compliance tests from nativejson-benchmark")
     {
         auto TEST_DOUBLE = [](const std::string & json_string, const double expected)
         {
-            CAPTURE(json_string);
-            CAPTURE(expected);
+            CAPTURE(json_string)
+            CAPTURE(expected)
             CHECK(json::parse(json_string)[0].get<double>() == Approx(expected));
         };
 
@@ -263,8 +264,8 @@ TEST_CASE("compliance tests from nativejson-benchmark")
     {
         auto TEST_STRING = [](const std::string & json_string, const std::string & expected)
         {
-            CAPTURE(json_string);
-            CAPTURE(expected);
+            CAPTURE(json_string)
+            CAPTURE(expected)
             CHECK(json::parse(json_string)[0].get<std::string>() == expected);
         };
 
@@ -319,12 +320,12 @@ TEST_CASE("compliance tests from nativejson-benchmark")
                     //"test/data/json_roundtrip/roundtrip32.json" // same as roundtrip31
                 })
         {
-            CAPTURE(filename);
+            CAPTURE(filename)
             std::ifstream f(filename);
             std::string json_string( (std::istreambuf_iterator<char>(f) ),
                                      (std::istreambuf_iterator<char>()) );
 
-            CAPTURE(json_string);
+            CAPTURE(json_string)
             json j = json::parse(json_string);
             CHECK(j.dump() == json_string);
         }
@@ -387,38 +388,37 @@ TEST_CASE("json.org examples")
     SECTION("FILE 1.json")
     {
         std::unique_ptr<std::FILE, decltype(&std::fclose)> f(std::fopen("test/data/json.org/1.json", "r"), &std::fclose);
-        json j;
-        CHECK_NOTHROW(j.parse(f.get()));
+        json _;
+        CHECK_NOTHROW(_ = json::parse(f.get()));
     }
 
     SECTION("FILE 2.json")
     {
         std::unique_ptr<std::FILE, decltype(&std::fclose)> f(std::fopen("test/data/json.org/2.json", "r"), &std::fclose);
-        json j;
-        CHECK_NOTHROW(j.parse(f.get()));
+        json _;
+        CHECK_NOTHROW(_ = json::parse(f.get()));
     }
 
     SECTION("FILE 3.json")
     {
         std::unique_ptr<std::FILE, decltype(&std::fclose)> f(std::fopen("test/data/json.org/3.json", "r"), &std::fclose);
-        json j;
-        CHECK_NOTHROW(j.parse(f.get()));
+        json _;
+        CHECK_NOTHROW(_ = json::parse(f.get()));
     }
 
     SECTION("FILE 4.json")
     {
         std::unique_ptr<std::FILE, decltype(&std::fclose)> f(std::fopen("test/data/json.org/4.json", "r"), &std::fclose);
-        json j;
-        CHECK_NOTHROW(j.parse(f.get()));
+        json _;
+        CHECK_NOTHROW(_ = json::parse(f.get()));
     }
 
     SECTION("FILE 5.json")
     {
         std::unique_ptr<std::FILE, decltype(&std::fclose)> f(std::fopen("test/data/json.org/5.json", "r"), &std::fclose);
-        json j;
-        CHECK_NOTHROW(j.parse(f.get()));
+        json _;
+        CHECK_NOTHROW(_ = json::parse(f.get()));
     }
-
 }
 
 TEST_CASE("RFC 7159 examples")
@@ -600,7 +600,7 @@ TEST_CASE("nst's JSONTestSuite")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
                 json j;
                 CHECK_NOTHROW(f >> j);
@@ -809,9 +809,10 @@ TEST_CASE("nst's JSONTestSuite")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
-                CHECK_THROWS_AS(json::parse(f), json::parse_error&);
+                json _;
+                CHECK_THROWS_AS(_ = json::parse(f), json::parse_error&);
             }
         }
 
@@ -841,7 +842,7 @@ TEST_CASE("nst's JSONTestSuite")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
                 json j;
                 CHECK_NOTHROW(f >> j);
@@ -864,7 +865,7 @@ TEST_CASE("nst's JSONTestSuite")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
                 json j;
                 CHECK_NOTHROW(f >> j);
@@ -884,7 +885,7 @@ TEST_CASE("nst's JSONTestSuite")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
                 json j;
                 CHECK_THROWS_AS(f >> j, json::out_of_range&);
@@ -911,7 +912,7 @@ TEST_CASE("nst's JSONTestSuite")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
                 json j;
                 CHECK_THROWS_AS(f >> j, json::parse_error&);
@@ -1026,9 +1027,10 @@ TEST_CASE("nst's JSONTestSuite (2)")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
-                CHECK_NOTHROW(json::parse(f));
+                json _;
+                CHECK_NOTHROW(_ = json::parse(f));
                 std::ifstream f2(filename);
                 CHECK(json::accept(f2));
             }
@@ -1227,9 +1229,10 @@ TEST_CASE("nst's JSONTestSuite (2)")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
-                CHECK_THROWS_AS(json::parse(f), json::parse_error&);
+                json _;
+                CHECK_THROWS_AS(_ = json::parse(f), json::parse_error&);
                 std::ifstream f2(filename);
                 CHECK(not json::accept(f2));
             }
@@ -1244,7 +1247,7 @@ TEST_CASE("nst's JSONTestSuite (2)")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
                 CHECK(not json::accept(f));
             }
@@ -1292,9 +1295,10 @@ TEST_CASE("nst's JSONTestSuite (2)")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
-                CHECK_NOTHROW(json::parse(f));
+                json _;
+                CHECK_NOTHROW(_ = json::parse(f));
                 std::ifstream f2(filename);
                 CHECK(json::accept(f2));
             }
@@ -1342,9 +1346,10 @@ TEST_CASE("nst's JSONTestSuite (2)")
                     }
                 )
             {
-                CAPTURE(filename);
+                CAPTURE(filename)
                 std::ifstream f(filename);
-                CHECK_THROWS_AS(json::parse(f), json::exception&); // could be parse_error or out_of_range
+                json _;
+                CHECK_THROWS_AS(_ = json::parse(f), json::exception&); // could be parse_error or out_of_range
                 std::ifstream f2(filename);
                 CHECK(not json::accept(f2));
             }
@@ -1352,6 +1357,8 @@ TEST_CASE("nst's JSONTestSuite (2)")
     }
 }
 
+namespace
+{
 std::string trim(const std::string& str);
 
 // from http://stackoverflow.com/a/25829178/266378
@@ -1365,6 +1372,7 @@ std::string trim(const std::string& str)
     size_t last = str.find_last_not_of(' ');
     return str.substr(first, (last - first + 1));
 }
+}
 
 TEST_CASE("Big List of Naughty Strings")
 {
@@ -1399,7 +1407,7 @@ TEST_CASE("Big List of Naughty Strings")
             }
 
             // check roundtrip
-            CAPTURE(line);
+            CAPTURE(line)
             json j = json::parse(line);
             CHECK(j.dump() == line);
         }
